import 'package:flutter_page_indicator/flutter_page_indicator.dart';
import 'package:flutter/material.dart';
import 'package:flutter_swiper/flutter_swiper.dart';
import 'package:responsive_builder/responsive_builder.dart';

import 'helper.dart';

class FotoGaleri extends StatelessWidget with Helper {
  ///  Orn: ['resimler/resim1.jpg' , 'resimler/resim2.jpg'] Buraya koseli parantez icerisinde gostremek istedigin resimlerin isimlerini tirnak icerisinde icindeki dosya adi ile birlikte yaz.
  final List<String> resimler;

  /// galerinin yuksekligini belirleri
  final int yukseklik;

  /// true-false; false yazarsan resimleri otomatik oynatmayi kapatir.
  final bool otomatikAnimasyon;

  /// true-false; false yazarsan resimleri sinirsiz kaydirmayi kapatir.
  final bool sinirsizKaydirma;

  /// true-false; true yazarsan  kaydirma yonu asagi yukari yonlu olur
  final bool asagiYukariKaydirma;

  /// Orn: 0.9, 0 ile 1 arasindaki ondalik sayilar.
  final double anaResminKaplamaOrani;

  /// 1 girersen resimleri merkezinden resmi bozmadan gosterir. 2 girersen resimleri cekerek gosterir
  final int resimHizalamaTuru;

  /// Colors. ile baslarsan on tanimli renkler gelir. Yada Ornek: 'de3234'.color  - 6 haneli renk kodunu tirnak icinde yazip .color yaz.
  final Color gostergeRengi;

  /// 0-9 arasinda bir sayi gir
  final int gostergeYeri;

  ///
  final List<Widget> resimUstuMenu;

  /// sayi gir
  final int koseYuvarlatma;

  /// Kayan resimler arasinda mesafe bbirak
  final int resimlerArasiMesafe;

  final bool otomatikYukseklik;
  FotoGaleri(
      {@required this.resimler,
      this.resimlerArasiMesafe = 0,
      this.resimUstuMenu = const [],
      this.koseYuvarlatma = 0,
      this.gostergeYeri = 8,
      this.gostergeRengi = Colors.amber,
      this.yukseklik = 500,
      this.otomatikAnimasyon = true,
      this.sinirsizKaydirma = false,
      this.asagiYukariKaydirma = false,
      this.anaResminKaplamaOrani = 1.0,
      this.otomatikYukseklik = false,
      this.resimHizalamaTuru = 1});

  @override
  Widget build(BuildContext context) {
    return ResponsiveBuilder(builder: (context, sizeInformation) {
      final double finalYukseklik = otomatikYukseklik == false || sizeInformation.localWidgetSize.width > 750 ? yukseklik.toDouble() : sizeInformation.localWidgetSize.width / 750 * yukseklik.toDouble();

      return Container(
        height: finalYukseklik,
        child: Swiper(
          itemBuilder: (BuildContext context, int index) {
            Widget current = ClipRRect(
                borderRadius: BorderRadius.circular(koseYuvarlatma.toDouble()),
                child: Image.asset(
                  resimler[index],
                  fit: resimHizalamaTuru == 1 ? BoxFit.cover : BoxFit.fill,
                  width: double.infinity,
                  height: finalYukseklik,
                ));

            if (resimlerArasiMesafe > 0) {
              current = Padding(
                child: current,
                padding: EdgeInsets.symmetric(horizontal: resimlerArasiMesafe.toDouble()),
              );
            }
            if (resimUstuMenu.length > 0 && resimUstuMenu.length > index) {
              current = Stack(
                children: <Widget>[
                  current,
                  resimUstuMenu[index],
                ],
              );
            }

            return current;
          },
          scrollDirection: !asagiYukariKaydirma ? Axis.horizontal : Axis.vertical,
          indicatorLayout: sinirsizKaydirma ? PageIndicatorLayout.SCALE : PageIndicatorLayout.WARM,
          autoplay: otomatikAnimasyon,
          autoplayDelay: 10000,
          duration: 1000,
          autoplayDisableOnInteraction: false,
          loop: sinirsizKaydirma,
          itemCount: resimler.length,
          pagination: new SwiperPagination(
              alignment: align(gostergeYeri),
              builder: DotSwiperPaginationBuilder(
                activeColor: gostergeRengi,
                color: gostergeRengi.withOpacity(0.2),
              )),
          control: new SwiperControl(color: gostergeRengi, disableColor: gostergeRengi.withOpacity(0.2), size: 20.0, padding: EdgeInsets.all(16.0)),
        ),
      );
    });
  }
}
