import 'package:flutter/material.dart';
import 'package:flutter_swiper/flutter_swiper.dart';
import 'package:mcg_simple_web_widget/arkaplan.dart';
import 'package:flutter_page_indicator/flutter_page_indicator.dart';

import 'helper.dart';

class KaydirmaPaneli extends StatelessWidget with Helper {
  KaydirmaPaneli({this.yukseklik, this.arkaplan, this.widgetlar, this.asagiYukariKaydirma = false, this.sinirsizKaydirma = false, this.gostergeYeri = 7, this.gostergeRengi = Colors.amber, this.otomatikAnimasyon = true});

  /// galerinin yuksekligini belirleri
  final double yukseklik;

  final Arkaplan arkaplan;

  final List<Widget> widgetlar;

  /// true-false; false yazarsan resimleri sinirsiz kaydirmayi kapatir.
  final bool sinirsizKaydirma;

  /// true-false; true yazarsan  kaydirma yonu asagi yukari yonlu olur
  final bool asagiYukariKaydirma;

  /// Colors. ile baslarsan on tanimli renkler gelir. Yada Ornek: 'de3234'.color  - 6 haneli renk kodunu tirnak icinde yazip .color yaz.
  final Color gostergeRengi;

  /// 0-9 arasinda bir sayi gir
  final int gostergeYeri;

  /// true-false; false yazarsan resimleri otomatik oynatmayi kapatir.
  final bool otomatikAnimasyon;
  @override
  Widget build(BuildContext context) {
    return Container(
      height: yukseklik,
      child: Stack(
        children: <Widget>[
          arkaplan ?? Container(),
          Swiper(
            itemBuilder: (BuildContext context, int index) {
              return Center(child: widgetlar[index]);
            },
            scrollDirection: !asagiYukariKaydirma ? Axis.horizontal : Axis.vertical,
            indicatorLayout: sinirsizKaydirma ? PageIndicatorLayout.SCALE : PageIndicatorLayout.WARM,
            autoplay: otomatikAnimasyon,
            autoplayDelay: 10000,
            duration: 1000,
            autoplayDisableOnInteraction: false,
            loop: sinirsizKaydirma,
            itemCount: widgetlar.length,
            pagination: new SwiperPagination(
                alignment: align(gostergeYeri),
                builder: DotSwiperPaginationBuilder(
                  activeColor: gostergeRengi,
                  color: gostergeRengi.withOpacity(0.2),
                )),
            control: new SwiperControl(color: gostergeRengi, disableColor: gostergeRengi.withOpacity(0.2), size: 20.0, padding: EdgeInsets.all(16.0)),
          ),
        ],
      ),
    );
  }
}
