import 'package:auto_animated_icon/auto_animated_icon.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:mcg_simple_web_widget/mcg_simple_web_widget.dart';
import 'package:mcg_simple_web_widget/ustbarbuyukwidget.dart';
import 'package:responsive_builder/responsive_builder.dart';
import 'package:scroll_to_index/scroll_to_index.dart';

const double _kBarButtonHeight = 50;

class UstBar extends StatefulWidget {
  /// Uygulamanin logosunu ismin yaninda gosterir. Kullanim sekli resmi once resimlerim klasoru icine koy. Sonra tirnak icerisinde 'resimler/resimadi.jpg' seklinde yaz.
  final String logo;

  /// Logonun boyutunu degistirir. Sayi girmelisin.
  final int logoBoyutu;

  /// Sitenin logo yanindaki adi. Ister Metin() widgeti koy. Istersen baska widgetlar koyabilirsin. Mesela Column koyup hem site adini altina sitenin kucuk sloganini yazabilirsin.
  final Widget siteAdi;

  /// Sag tarafa istedigin kadar tus koyar. Once koseli parantez acmalisin. Sonra icerisine istedigin kadar UstBarTusu koyabilirsisn. Orn: [UstBarTusu(),UstBarTusu(),]
  final List<UstBarTusu> tuslar;

  /// Ust barin arka plan rengi. Colors. yazip on tanimli renkleri acabilirsin yada 6 haneli renk kodunu tirnak icinde yazip .color yazabilirsin. Ornek: '32ed4e'.color
  final Color arkaPlanRengi;

  /// Cubuk kuculdugunde gelen menu buton rengi. Colors. yazip on tanimli renkleri acabilirsin yada 6 haneli renk kodunu tirnak icinde yazip .color yazabilirsin. Ornek: '32ed4e'.color
  final Color menuButtonColor;

  final Widget ustBarBuyukWidget;
  UstBar({this.logo, this.logoBoyutu = 56, this.ustBarBuyukWidget, this.siteAdi, this.tuslar, this.arkaPlanRengi = Colors.white, this.menuButtonColor = const Color(0xff55BAD1)});

  @override
  _UstBarState createState() => _UstBarState();
}

class _UstBarState extends State<UstBar> with TickerProviderStateMixin {
  bool isOpen = false;

  @override
  Widget build(BuildContext context) {
    return ResponsiveBuilder(
      builder: (context, sizingInformation) {
        if (sizingInformation.localWidgetSize.width > 750) {
          return Column(
            children: <Widget>[
              Container(
                color: widget.arkaPlanRengi,
                padding: const EdgeInsets.symmetric(vertical: 16, horizontal: 16),
                child: Row(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  mainAxisSize: MainAxisSize.max,
                  children: <Widget>[
                    Spacer(
                      flex: 1,
                    ),
                    if (widget.logo != null)
                      Image.asset(
                        widget.logo,
                        width: widget.logoBoyutu.toDouble(),
                      ),
                    SizedBox(
                      width: 12,
                    ),
                    widget.siteAdi,
                    Spacer(
                      flex: 5,
                    ),
                    Row(
                      children: widget.tuslar ?? [],
                    ),
                    Spacer(
                      flex: 1,
                    ),
                  ],
                ),
              ),
              if (widget.ustBarBuyukWidget != null) widget.ustBarBuyukWidget
            ],
          );
        }

        return Container(
          color: widget.arkaPlanRengi,
          child: Column(
            children: <Widget>[
              Container(
                color: widget.arkaPlanRengi,
                width: double.infinity,
                alignment: Alignment.center,
                padding: EdgeInsets.only(top: 16, bottom: 16),
                child: Row(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  mainAxisSize: MainAxisSize.min,
                  children: <Widget>[
                    if (widget.logo != null)
                      Image.asset(
                        widget.logo,
                        width: widget.logoBoyutu.toDouble(),
                      ),
                    SizedBox(
                      width: 12,
                    ),
                    widget.siteAdi,
                  ],
                ),
              ),
              Stack(
                alignment: Alignment.topCenter,
                fit: StackFit.passthrough,
                children: <Widget>[
                  Column(
                    children: <Widget>[
                      AnimatedSize(
                        vsync: this,
                        duration: Duration(milliseconds: 333),
                        alignment: Alignment.topCenter,
                        child: !isOpen
                            ? SizedBox()
                            : Container(
                                margin: EdgeInsets.only(top: 40),
                                color: widget.arkaPlanRengi,
                                child: Column(
                                  children: widget.tuslar ?? [],
                                ),
                              ),
                      ),
                      if (widget.ustBarBuyukWidget != null) Padding(padding: EdgeInsets.only(top: 24), child: widget.ustBarBuyukWidget),
                    ],
                  ),
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: <Widget>[
                      CircleAvatar(
                        backgroundColor: widget.arkaPlanRengi,
                        radius: 24,
                        child: CircleAvatar(
                          radius: 20,
                          backgroundColor: widget.menuButtonColor,
                          child: AutoAnimatedIcon(
                            padding: EdgeInsets.zero,
                            onPressed: () {
                              setState(() {
                                isOpen = !isOpen;
                              });
                            },
                            iconState: !isOpen ? IconState.first : IconState.second,
                            color: Colors.white,
                            hoverColor: Colors.grey,
                            icon: AnimatedIcons.menu_close,
                          ),
                        ),
                      ),
                    ],
                  ),
                ],
              ),
            ],
          ),
        );
      },
    );
  }
}

class UstBarTusu extends StatelessWidget {
  ///Tusun ismini tirnak icerisinde gir
  String isim;

  /// Tus secili iken ki rengi. Colors. yazip on tanimli renkleri acabilirsin yada 6 haneli renk kodunu tirnak icinde yazip .color yazabilirsin. Ornek: '32ed4e'.color
  //final Color aktifRengi;

  /// Tus secili degilken ki rengi. Colors. yazip on tanimli renkleri acabilirsin yada 6 haneli renk kodunu tirnak icinde yazip .color yazabilirsin. Ornek: '32ed4e'.color
  final Color pasifRengi;

  /// Fare uerine gelince ki rengi. Colors. yazip on tanimli renkleri acabilirsin yada 6 haneli renk kodunu tirnak icinde yazip .color yazabilirsin. Ornek: '32ed4e'.color
  final Color yariAktifRengi;

  /// Fare uerine gelince ki rengi. Colors. yazip on tanimli renkleri acabilirsin yada 6 haneli renk kodunu tirnak icinde yazip .color yazabilirsin. Ornek: '32ed4e'.color
  final Color yaziRengi;

  final int bolumNo;
  final AutoScrollController kaydirmaKontrolu;

  UstBarTusu(
      {this.isim = '',
      //   this.aktifRengi=const Color(0xff55BAD1),
      this.pasifRengi = Colors.white,
      this.yariAktifRengi = const Color(0xff55BAD1),
      this.yaziRengi = const Color(0xff000000),
      this.bolumNo,
      this.kaydirmaKontrolu});

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: 4.0, vertical: 4),
      child: new RaisedButton(
        elevation: 0,
        hoverElevation: 1,
        padding: EdgeInsets.symmetric(vertical: 4, horizontal: 8),
        hoverColor: yariAktifRengi,
        color: pasifRengi,
        child: Text(
          isim,
          style: TextStyle(color: yaziRengi, fontWeight: FontWeight.w200),
        ),
        onPressed: () {
          (kaydirmaKontrolu ?? autoScrollController).scrollToIndex(bolumNo, preferPosition: AutoScrollPosition.begin);
        },
      ),
    );
  }
}
