import 'package:flutter/material.dart';

import 'image.dart';

///CircularProfileAvatar allows developers to implement circular profile avatar with border,
/// overlay, initialsText and many other features which simplifies developer's job.
/// It is an alternative to Flutter's CircleAvatar
class YuvarlakWidget extends StatelessWidget {
  YuvarlakWidget({
    Key key,
    this.arkaplanResmi,
    this.child = const Text(''),
    this.yaricap = 50.0,
    this.cerceveGenisligi = 0.0,
    this.cerceveRengi = Colors.white,
    this.arkaplanRengi = Colors.white,
    this.golgeYuksekligi = 0.0,
    this.showInitialTextAbovePicture = true,
    this.filtreRengi = Colors.transparent,
  }) : super(key: key);

  final double yaricap;

  /// sets shadow of the circle,
  /// default value is 0.0
  final double golgeYuksekligi;

  /// sets the borderWidth of the circile,
  /// default value is 0.0
  final double cerceveGenisligi;

  /// The color with which to fill the border of the circle.
  /// default value [Colors.white]
  final Color cerceveRengi;

  /// The color with which to fill the circle.
  /// default value [Colors.white]
  final Color arkaplanRengi;

  /// sets the [filtreRengi] of the circle, It only works if [showInitialTextAbovePicture] is set to true.
  /// [filtreRengi] doesn't include border of the circle.
  final Color filtreRengi;

  /// it takes a URL of the profile image.
  final String arkaplanResmi;

  /// Sets the initials of user's name.
  final Widget child;

  /// Displays initials above profile picture if set to true, You can set [filtreRengi] value as well if [showInitialTextAbovePicture]
  /// is set to true.
  final bool showInitialTextAbovePicture;

  Widget _initialsText;

  @override
  Widget build(BuildContext context) {
    _initialsText = Center(child: child);
    return Material(
      type: MaterialType.circle,
      elevation: golgeYuksekligi,
      color: cerceveRengi,
      child: Container(
          height: yaricap * 2,
          width: yaricap * 2,
          padding: EdgeInsets.all(cerceveGenisligi),
          decoration: BoxDecoration(borderRadius: BorderRadius.circular(yaricap), color: cerceveRengi),
          child: Center(
            child: Container(
                decoration: BoxDecoration(color: arkaplanRengi, borderRadius: BorderRadius.circular(yaricap)),
                child: Stack(
                  fit: StackFit.expand,
                  children: arkaplanResmi == null
                      ? <Widget>[_initialsText]
                      : showInitialTextAbovePicture
                          ? <Widget>[
                              profileImage(),
                              _initialsText,
                            ]
                          : <Widget>[
                              _initialsText,
                              profileImage(),
                            ],
                )),
          )),
    );
  }

  Widget profileImage() {
    return ClipRRect(
      borderRadius: BorderRadius.circular(yaricap),
      child: filtreRengi == null
          ? Resim(
              resimYolu: arkaplanResmi,
              yukseklik: (yaricap * 2).toInt(),
              genislik: (yaricap * 2).toInt(),
            )
          : Stack(
              children: <Widget>[
                Resim(
                  resimYolu: arkaplanResmi,
                  yukseklik: (yaricap * 2).toInt(),
                  genislik: (yaricap * 2).toInt(),
                ),
                Card(
                  margin: EdgeInsets.zero,
                  color: filtreRengi.withOpacity(0.4),
                  shape: CircleBorder(),
                  child: SizedBox(
                    width: (yaricap * 2).toDouble(),
                    height: (yaricap * 2).toDouble(),
                  ),
                )
              ],
            ),
    );
  }
}
